@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2022 by the Free Software Foundation, Inc.
+# Copyright (C) 2010-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -23,7 +23,7 @@ import unittest
 from contextlib import ExitStack, redirect_stderr
 from datetime import datetime, timedelta
 from enum import Enum
-from importlib_resources import open_binary
+from importlib.resources import open_binary
 from io import StringIO
 from mailman.app.lifecycle import create_list
 from mailman.config import config
@@ -330,6 +330,15 @@ class TestBasicImport(unittest.TestCase):
         self.assertEqual('This is text.\n',
                          self._mlist.dmarc_wrapped_message_text)
 
+    def test_dmarc_addresses(self):
+        self._pckdict['dmarc_moderation_addresses'] = [
+            b'user@example.com',
+            b'^.*@gmail.com',
+            ]
+        self._import()
+        self.assertEqual(['user@example.com', '^.*@gmail.com'],
+                         self._mlist.dmarc_addresses)
+
     def test_ban_list(self):
         banned = [
             ('anne@example.net', 'anne@example.net'),
